<nav aria-label="breadcrumb">
	<ol class="breadcrumb">
	{% for node in cruditor.breadcrumb %}
		<li class="breadcrumb-item{% if forloop.last %} active{% endif %}"{% if forloop.last %} aria-current="page"{% endif %}>
			{% if node.url %}
				<a href="{{ node.url }}">{{ node.title }}</a>
			{% else %}
				{{ node.title }}
			{% endif %}
		</li>
	{% endfor %}
	</ol>
</nav>
